measuretools.get_previous_measure_from_component
================================================

.. autofunction:: abjad.tools.measuretools.get_previous_measure_from_component.get_previous_measure_from_component
   :noindex:
